package com.csm.huahai.web.mapper.coremapper;

import com.csm.huahai.web.dto.WycCheckDataDto;
import com.csm.huahai.web.dto.ZabacheckDataDto;
import com.csm.huahai.web.dto.WycCheckDto;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface WycDataContrastMapper {

    /**
     * 人口基本信息查询
     * @param idCard
     * @return
     */
    Map<String, String> getPersonMessageBasic(@Param("idCard") String idCard);

    /**
     * 查询居住证
     * @param idCard
     * @return
     */
    List<String> getResidencePermit(@Param("idCard")String idCard);

    /**
     * 吸毒记录
     * @param idCard
     * @return
     */
    List<String> getDrugTakingRecord(@Param("idCard")String idCard);

    /**
     * 酒驾记录
     * @param idCard
     * @return
     */
    List<Map<String,String>> getDrunkDrivingRecord(@Param("idCard")String idCard);

    /**
     * 驾驶证字典翻译
     * @param driverLicenseStatus
     * @return
     */
    String getDriverLicenseStatusCN(@Param("driverLicenseStatus")List<Character> driverLicenseStatus);

    /**
     * 全国在逃人员检索
     * @param idCard
     * @return
     */
    List<Map<String,String>> getNationalFugitivePersonnelSearch(@Param("idCard")String idCard);

    /**
     * 全国违法犯罪背景
     * @param idCard
     * @return
     */
    List<Map<String,String>> getNationalDelinquencyIndex(@Param("idCard")String idCard);

    /**
     * 拘留所背景索引
     * @param idCard
     * @return
     */
    List<Map<String, String>> getDetentionFacilityIndex(@Param("idCard")String idCard);

    /**
     * 看守所背景索引
     * @param idCard
     * @return
     */
    List<Map<String, String>> getPrisonIndex(@Param("idCard")String idCard);

    /**
     * 查询流水信息发证时间是否大于三年
     * @param idCard
     * @return
     */
    int getFlowMessageNum(@Param("idCard")String idCard);

    /**
     * 根据案件代码查询看守所数据
     * @param idCard
     * @param ajcodeList
     * @return
     */
    List<Map<String, String>> getPrisonMessageByAjCode(@Param("idCard")String idCard,@Param("ajlb")String ajlb, @Param("ajcodeList")List<String> ajcodeList);

    /**
     * 根据身份证号查询看守所数据
     * @param idCard
     * @return
     */
    List<Map<String, String>> getPrisonMessageByIdCard(@Param("idCard")String idCard);

    /**
     * 是否涉恐人员查询
     * @param idCard
     * @return
     */
    int getTerrorismKeynotePeople(@Param("idCard")String idCard);

    /**
     * 吸毒详情
     * @param xyrbh
     * @return
     */
    List<Map<String, String>> getDrugTakingDetail(@Param("xyrbh")String xyrbh);

    /**
     * 根据违法犯罪信息模糊查询拘留所信息
     * @param idCard
     * @param wfxz
     * @return
     */
    List<Map<String, String>> getJlsxxByWfxz(@Param("idCard")String idCard,@Param("wfxz")String wfxz);

    /**
     * 查询死亡信息
     * @param idCard
     * @return
     */
    List<Map<String, String>> getDeathMessage(@Param("idCard")String idCard);

    /**
     * 查询死亡信息
     * @param idCard
     * @return
     */
    List<String> getswxx(@Param("idCard")String idCard);

    /**
     * 新增网约车审核
     * @param wycCheckDto
     * @return
     */
    int addWycDataCheck(WycCheckDto wycCheckDto);

    /**
     * 新增网约车审核详情
     * @param wycCheckDataDto
     * @return
     */
    int addWycDataCheckDetail(WycCheckDataDto wycCheckDataDto);

    /**
     * 同步到治安备案系统岗前审核表中岗前
     * @param zabacheckDataDto
     * @return
     */
    int addWycDataCheckDetailGQ (ZabacheckDataDto zabacheckDataDto);

    /**
     * 同步到治安备案系统岗前审核表中动态
     * @param zabacheckDataDto
     * @return
     */
    int addWycDataCheckDetailDT (ZabacheckDataDto zabacheckDataDto);

    /**
     * 获取网约车审核详情
     * @param pch
     * @return
     */
    List<WycCheckDataDto> getWycDataCheckDetail(@Param("pch")String pch);

    /**
     * 获取审核列表
     * @return
     */
    List<WycCheckDto> getList(@Param("pch")String pch,@Param("idCardNum")String idCardNum);

    /**
     * 修改状态
     * @param pch
     */
    void updateWycCheckDataStatus(@Param("pch")String pch);

    /**
     * 获取黑名单信息
     * @param idCardNum
     * @return
     */
    List<String> getHmdqk(@Param("idCardNum")String idCardNum);

}
