package com.csm.huahai.common.config.mybaties;

import com.csm.huahai.common.utils.StringUtils;
import org.apache.ibatis.io.VFS;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.mybatis.spring.boot.autoconfigure.SpringBootVFS;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;
import org.springframework.core.io.DefaultResourceLoader;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

/**
 * @author taoyuan
 * @date 2024/12/10
 */
@Configuration
@MapperScan(basePackages="com.csm.huahai.web.mapper.secondmapper",sqlSessionFactoryRef = "driverSqlSessionFactory")
public class DriverMessageMybatisConfig extends MybatiesConfig {

    @Autowired
    private Environment env;

    @Autowired
    @Qualifier("driverDataSource")
    DataSource dataSource;


    @Bean(name="driverSqlSessionFactory")
    public SqlSessionFactory testSqlSessionFactory() throws Exception
    {

        String typeAliasesPackage = env.getProperty("mybatis.typeAliasesPackage");
        String mapperLocations = env.getProperty("mybatis.mapperLocations");
        String configLocation = env.getProperty("mybatis.configLocation");
        //typeAliasesPackage = setTypeAliasesPackage(typeAliasesPackage);
        VFS.addImplClass(SpringBootVFS.class);

        SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(dataSource);
        sessionFactory.setTypeAliasesPackage(typeAliasesPackage);
        sessionFactory.setMapperLocations(resolveMapperLocations(StringUtils.split(mapperLocations, ",")));
        sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver().getResources("classpath:mapper/secondmapper/*.xml"));
        sessionFactory.setConfigLocation(new DefaultResourceLoader().getResource(configLocation));
        return sessionFactory.getObject();
    }

    @Bean(name="driverSqlSessionTemplate")
    SqlSessionTemplate testSqlSessionTemplate()throws Exception{
        return new SqlSessionTemplate(testSqlSessionFactory());
    }

    @Bean(name="driverTransactionManager")
    public DataSourceTransactionManager testTransactionManager() {
        return new DataSourceTransactionManager(dataSource);
    }

}
