package com.csm.huahai.common.customthread;

import java.util.concurrent.*;

public class CustomThreadPoolManager {

    private static CustomThreadPoolManager instance;

    private final ThreadPoolExecutor threadPool;

    private CustomThreadPoolManager(){
        int corePoolSize = 64;
        int maxpoolSize = 200;
        long keepAliveTime = 60L;
        TimeUnit unit = TimeUnit.SECONDS;
        BlockingQueue<Runnable> workQueue = new LinkedBlockingQueue<>();
        ThreadFactory threadFactory = Executors.defaultThreadFactory();
        RejectedExecutionHandler handler = new ThreadPoolExecutor.CallerRunsPolicy();

        this.threadPool = new ThreadPoolExecutor(
                corePoolSize,
                maxpoolSize,
                keepAliveTime,
                unit,
                workQueue,
                threadFactory,
                handler
        );
    }

    public static synchronized CustomThreadPoolManager getInstance(){
        if(instance==null){
            instance = new CustomThreadPoolManager();
        }
        return instance;
    }

    //提交任务到线程池
    public void execute(Runnable task){
        threadPool.execute(task);
    }

    //提交带有返回值的任务
    public <T> Future<T> submit(Callable<T> task){
        return threadPool.submit(task);
    }

    //关闭线程池（等待所有任务完成后关闭）
    public void shutdown(){
        threadPool.shutdown();
        try{
            if(!threadPool.awaitTermination(80,TimeUnit.MILLISECONDS)){
                threadPool.shutdownNow();
            }
        }catch (InterruptedException e){
            threadPool.shutdownNow();
        }
    }

    //强制关闭线程池
    public void shutdownNow(){
        threadPool.shutdownNow();
    }
}
